@@ -83,7 +83,8 @@ class Worker:
 
     def stop_woker(self, func_name):
         error = f'Error in {func_name}: worker.is_alive() => os.kill(os.getpid(), signal.SIGINT)'
-        database.set_worker_error(error, self._worker, self._current_task)
+        if self._worker:
+            database.set_worker_error(error, self._worker, self._current_task)
         try:
             # sys.exit(1)
             import signal
@@ -141,7 +142,8 @@ class Worker:
                     else:
                         error = f'Error in {func_name}: worker({process_type}).is_alive() => sys.exit(1)'
                         logger.error(error)
-                        database.set_worker_error(error, self._worker, self._current_task)
+                        if self._worker:
+                            database.set_worker_error(error, self._worker, self._current_task)
                         sys.exit(1)
                 else:
                     if not worker_queue.empty():
@@ -160,7 +162,8 @@ class Worker:
                 timer.cancel()
             if exception:
                 if self._raise_exception:
-                    database.set_worker_error(error, self._worker, self._current_task)
+                    if self._worker:
+                        database.set_worker_error(error, self._worker, self._current_task)
                     raise exception
                 else:
                     database.update_worker_task({'status': 'error', 'result': error}, self._current_task,
@@ -173,9 +176,10 @@ class Worker:
                     if time_delta_sec > self._life_timeout_sec:
                         logger.info(f'{func_name}; time_delta_sec({time_delta_sec})'
                                     f' > life_timeout_sec({self._life_timeout_sec}) => return...')
-                        self._worker.status = 'finished'
-                        self._worker.finished_time = datetime.datetime.now()
-                        database.session.commit()
+                        if self._worker:
+                            self._worker.status = 'finished'
+                            self._worker.finished_time = datetime.datetime.now()
+                            database.session.commit()
                         return
                 threading.Timer(self._sleep_sec, self._do_task, args=(process_type,)).start()
 
@@ -192,6 +196,7 @@ class Worker:
 
         process_type = None
         loops_limit = 20
+        create_db_worker = False
         worker_cfg = config.cfg.get('worker')
 
         if isinstance(worker_cfg, dict):
@@ -221,8 +226,8 @@ class Worker:
             if process_type.lower() not in ['fork', 'thread', 'kthread']:
                 logger.error(f'Error in {func_name}: unknown process_type "{process_type}"...')
                 return
-
-        self._worker = database.get_new_worker()
+        if create_db_worker:
+            self._worker = database.get_new_worker()
         self._started = True
         self._started_timestamp = datetime.datetime.now()
         if self._blocking:
@@ -243,9 +248,10 @@ class Worker:
                         break
                 if self._sleep_sec is not None:
                     time.sleep(self._sleep_sec)
-            self._worker.status = 'finished'
-            self._worker.finished_time = datetime.datetime.now()
-            database.session.commit()
+            if self._worker:
+                self._worker.status = 'finished'
+                self._worker.finished_time = datetime.datetime.now()
+                database.session.commit()
         else:
             self._do_task(process_type)
 
@@ -255,8 +261,8 @@ class Worker:
 
 if __name__ == '__main__':
     name = 'Worker'
-    ver = '1.2'
-    release_date = '2020-06-05 11:15'
+    ver = '1.3'
+    release_date = '2020-06-05 11:45'
     version = f'{name}. ver: {ver} ({release_date})'
     from pg_tasks_queue.Logging import init_logger
     init_logger()
